@@ -1,6 +1,6 @@
 package Pcore::App::Nginx;
 
-use Pcore qw[-class];
+use Pcore -class;
 
 extends qw[Pcore::App::Alien];
 
@@ -21,7 +21,7 @@ sub cli_name ($self) {
 }
 
 sub _build_nginx_ver ($self) {
-    return $self->cfg->{NGINX}->{NGINX_VER} || $PROC->{CFG}->{NGINX}->{NGINX_VER};
+    return $self->cfg->{NGINX}->{NGINX_VER} || $ENV->{CFG}->{NGINX}->{NGINX_VER};
 }
 
 # APP
@@ -54,7 +54,7 @@ around app_build => sub ( $orig, $self ) {
         $self->_appx_report_warn( q["] . $self->alien_dir . q[" already exists. Remove it manually to rebuild] );
     }
     else {
-        require Archive::Tar;
+        state $init = !!require Archive::Tar;
 
         my $module = {
             nginx_http_auth_request_module => {
@@ -102,7 +102,7 @@ around app_build => sub ( $orig, $self ) {
         my $cv = AE::cv;
 
         # nginx
-        P->ua->get(
+        P->http->get(
             'http://nginx.org/download/nginx-' . $self->nginx_ver . '.tar.gz',
             buf_size    => 1,
             blocking    => $cv,
@@ -115,8 +115,8 @@ around app_build => sub ( $orig, $self ) {
         );
 
         # pcre
-        P->ua->get(
-            qq[http://nchc.dl.sourceforge.net/project/pcre/pcre/$PROC->{CFG}->{NGINX}->{PCRE_VER}/pcre-$PROC->{CFG}->{NGINX}->{PCRE_VER}.tar.gz],
+        P->http->get(
+            qq[http://nchc.dl.sourceforge.net/project/pcre/pcre/$ENV->{CFG}->{NGINX}->{PCRE_VER}/pcre-$ENV->{CFG}->{NGINX}->{PCRE_VER}.tar.gz],
             buf_size    => 1,
             blocking    => $cv,
             on_progress => 1,
@@ -129,7 +129,7 @@ around app_build => sub ( $orig, $self ) {
 
         # third party modules
         for my $module_name ( grep { $module->{$_}->{enabled} } keys $module->%* ) {
-            P->ua->get(
+            P->http->get(
                 $module->{$module_name}->{url},
                 buf_size    => 1,
                 blocking    => $cv,
@@ -165,7 +165,7 @@ around app_build => sub ( $orig, $self ) {
                 '--with-http_sub_module',
                 '--with-http_gzip_static_module',
                 '--with-http_perl_module',
-                '--with-pcre=' . $build_dir . 'pcre-' . $PROC->{CFG}->{NGINX}->{PCRE_VER},
+                '--with-pcre=' . $build_dir . 'pcre-' . $ENV->{CFG}->{NGINX}->{PCRE_VER},
                 '--with-pcre-jit',
                 map { '--add-module=' . $build_dir . $module->{$_}->{path} } grep { $module->{$_}->{enabled} } keys $module->%*,
             );
@@ -230,11 +230,11 @@ sub generate_alien_cfg ($self) {
         app_name           => $self->name,
         app_dir            => $self->app_dir,
         alien_dir          => $self->alien_dir,
-        log_dir            => $PROC->{LOG_DIR},
+        log_dir            => $ENV->{LOG_DIR},
         vhosts_dir         => $self->app_dir . 'vhosts',
-        geoip_country_path => P->geoip->country_path,
-        geoip_city_path    => P->geoip->city_path,
-        ssl                => 0,                           # $self->openssl->is_enabled, # TODO
+        geoip_country_path => $ENV->res->get('/data/geoip_country.dat'),
+        geoip_city_path    => $ENV->res->get('/data/geoip_city.dat'),
+        ssl                => 0,                                           # $self->openssl->is_enabled, # TODO
     };
 
     $cfg = P->tmpl( type => 'text' )->render( 'nginx/server.nginx', $params );
@@ -248,7 +248,7 @@ sub master_proc ($self) {
 
     # плавное завершение
     $SIG->{QUIT} = AE::signal QUIT => sub {
-        debug 'SIGQUIT received';
+        P->log->debug('SIGQUIT received');
 
         $self->term_state(1);
 
@@ -257,30 +257,30 @@ sub master_proc ($self) {
 
     # изменение конфигурации, обновление изменившейся временной зоны (только для FreeBSD и Linux), запуск новых рабочих процессов с новой конфигурацией, плавное завершение старых рабочих процессов
     $SIG->{HUP} = AE::signal HUP => sub {
-        debug 'SIGHUP received';
+        P->log->debug('SIGHUP received');
 
         kill 'HUP', $self->alien_pid;     ## no critic qw[InputOutput::RequireCheckedSyscalls]
     };
 
     # переоткрытие лог-файлов
     $SIG->{USR1} = AE::signal USR1 => sub {
-        debug 'SIGUSR1 received';
+        P->log->debug('SIGUSR1 received');
 
         kill 'USR1', $self->alien_pid;    ## no critic qw[InputOutput::RequireCheckedSyscalls]
     };
 
     # обновление исполняемого файла
     $SIG->{USR2} = AE::signal USR2 => sub {
-        debug 'SIGUSR2 received';
+        P->log->debug('SIGUSR2 received ');
 
-        kill 'USR2', $self->alien_pid;    ## no critic qw[InputOutput::RequireCheckedSyscalls]
+        kill ' USR2 ', $self->alien_pid;    ## no critic qw[InputOutput::RequireCheckedSyscalls]
     };
 
     # плавное завершение рабочих процессов
     $SIG->{WINCH} = AE::signal WINCH => sub {
-        debug 'SIGWINCH received';
+        P->log->debug(' SIGWINCH received ');
 
-        kill 'WINCH', $self->alien_pid;    ## no critic qw[InputOutput::RequireCheckedSyscalls]
+        kill ' WINCH ', $self->alien_pid;    ## no critic qw[InputOutput::RequireCheckedSyscalls]
     };
 
     return;
