@@ -1,6 +1,6 @@
-package Pcore::Nginx v0.2.2;
+package Pcore::Nginx v0.2.3;
 
-use Pcore qw[-class];
+use Pcore -class;
 
 1;
 __END__
